@@ -1,6 +1,7 @@
 from __future__ import annotations
 
-from steamship.base import Request, Response
+from steamship.base.request import Request
+from steamship.base.response import Response
 
 from ..file import File
 
@@ -11,7 +12,7 @@ class TagRequest(Request):
     name: str = None
     handle: str = None
     plugin_instance: str = None
-    file: File.CreateRequest = None
+    file: File = None
 
 
 class TagResponse(Response):
